chown_data = {
    'imports': [
        (0x220fd80, 8, 9, '*.endgrent'),
        (0x220fd88, 8, 9, '*.__uflow'),
        (0x220fd90, 8, 9, '*.getenv'),
        (0x220fd98, 8, 9, '*.abort'),
        (0x220fda0, 8, 9, '*.__errno_location'),
        (0x220fda8, 8, 9, '*.strncmp'),
        (0x220fdb0, 8, 9, '*._exit'),
        (0x220fdb8, 8, 9, '*.strcpy'),
        (0x220fdc0, 8, 9, '*.__fpending'),
        (0x220fdc8, 8, 9, '*.qsort'),
        (0x220fdd0, 8, 9, '*.fcntl'),
        (0x220fdd8, 8, 9, '*.textdomain'),
        (0x220fde0, 8, 9, '*.fclose'),
        (0x220fde8, 8, 9, '*.getpwuid'),
        (0x220fdf0, 8, 9, '*.bindtextdomain'),
        (0x220fdf8, 8, 9, '*.stpcpy'),
        (0x220fe00, 8, 9, '*.dcgettext'),
        (0x220fe08, 8, 9, '*.__ctype_get_mb_cur_max'),
        (0x220fe10, 8, 9, '*.strlen'),
        (0x220fe18, 8, 9, '*.__lxstat'),
        (0x220fe20, 8, 9, '*.openat'),
        (0x220fe28, 8, 9, '*.__stack_chk_fail'),
        (0x220fe30, 8, 9, '*.getopt_long'),
        (0x220fe38, 8, 9, '*.mbrtowc'),
        (0x220fe40, 8, 9, '*.strchr'),
        (0x220fe48, 8, 9, '*.getgrgid'),
        (0x220fe50, 8, 9, '*.__fxstatat'),
        (0x220fe58, 8, 9, '*.strrchr'),
        (0x220fe60, 8, 9, '*.lseek'),
        (0x220fe68, 8, 9, '*.__assert_fail'),
        (0x220fe70, 8, 9, '*.memset'),
        (0x220fe78, 8, 9, '*.fscanf'),
        (0x220fe80, 8, 9, '*.close'),
        (0x220fe88, 8, 9, '*.__openat_2'),
        (0x220fe90, 8, 9, '*.closedir'),
        (0x220fe98, 8, 9, '*.memcmp'),
        (0x220fea0, 8, 9, '*.fputs_unlocked'),
        (0x220fea8, 8, 9, '*.calloc'),
        (0x220feb0, 8, 9, '*.strcmp'),
        (0x220feb8, 8, 9, '*.dirfd'),
        (0x220fec0, 8, 9, '*.getpwnam'),
        (0x220fec8, 8, 9, '*.memcpy'),
        (0x220fed0, 8, 9, '*.getgrnam'),
        (0x220fed8, 8, 9, '*.fileno'),
        (0x220fee0, 8, 9, '*.__xstat'),
        (0x220fee8, 8, 9, '*.readdir'),
        (0x220fef0, 8, 9, '*.malloc'),
        (0x220fef8, 8, 9, '*.fflush'),
        (0x220ff00, 8, 9, '*.nl_langinfo'),
        (0x220ff08, 8, 9, '*.ungetc'),
        (0x220ff10, 8, 9, '*.__fxstat'),
        (0x220ff18, 8, 9, '*.endpwent'),
        (0x220ff20, 8, 9, '*.__freading'),
        (0x220ff28, 8, 9, '*.fchdir'),
        (0x220ff30, 8, 9, '*.realloc'),
        (0x220ff38, 8, 9, '*.fdopen'),
        (0x220ff40, 8, 9, '*.setlocale'),
        (0x220ff48, 8, 9, '*.__printf_chk'),
        (0x220ff50, 8, 9, '*.memmove'),
        (0x220ff58, 8, 9, '*.error'),
        (0x220ff60, 8, 9, '*.open'),
        (0x220ff68, 8, 9, '*.fseeko'),
        (0x220ff70, 8, 9, '*.fchown'),
        (0x220ff78, 8, 9, '*.fdopendir'),
        (0x220ff80, 8, 9, '*.strtoul'),
        (0x220ff88, 8, 9, '*.fstatfs'),
        (0x220ff90, 8, 9, '*.__cxa_atexit'),
        (0x220ff98, 8, 9, '*.fchownat'),
        (0x220ffa0, 8, 9, '*.exit'),
        (0x220ffa8, 8, 9, '*.fwrite'),
        (0x220ffb0, 8, 9, '*.__fprintf_chk'),
        (0x220ffb8, 8, 9, '*.mbsinit'),
        (0x220ffc0, 8, 9, '*.iswprint'),
        (0x220ffc8, 8, 9, '*.__ctype_b_loc'),
        (0x220ffd0, 8, 9, '*.free'),
        (0x220ffd8, 8, 9, '*._ITM_deregisterTMCloneTable'),
        (0x220ffe0, 8, 9, '*.__libc_start_main'),
        (0x220ffe8, 8, 9, '*.__gmon_start__'),
        (0x220fff0, 8, 9, '*._ITM_registerTMCloneTable'),
        (0x220fff8, 8, 9, '*.__cxa_finalize'),
    ],

    'exports': [
        (0x20027a0, 0, '__entry', 'chown'),
        (0x2008420, 0, 'fts_open', 'chown'),
        (0x20087c0, 0, 'fts_close', 'chown'),
        (0x2008950, 0, 'fts_read', 'chown'),
        (0x20090d0, 0, 'fts_set', 'chown'),
        (0x2009100, 0, 'fts_children', 'chown'),
        (0x200b0a0, 1, '_IO_stdin_used', 'chown'),
        (0x200c5e0, 1, 'quoting_style_vals', 'chown'),
        (0x200c960, 1, 'version_etc_copyright', 'chown'),
        (0x220fb20, 1, 'quoting_style_args', 'chown'),
        (0x2210010, 1, 'Version', 'chown'),
        (0x2210018, 1, 'exit_failure', 'chown'),
        (0x2210020, 1, 'quote_quoting_options', 'chown'),
        (0x2210080, 1, '__progname', 'chown'),
        (0x2210080, 1, 'program_invocation_short_name', 'chown'),
        (0x2210088, 1, 'stdout', 'chown'),
        (0x2210090, 1, 'optind', 'chown'),
        (0x22100a0, 1, 'optarg', 'chown'),
        (0x22100a8, 1, '__progname_full', 'chown'),
        (0x22100a8, 1, 'program_invocation_name', 'chown'),
        (0x22100c0, 1, 'stderr', 'chown'),
        (0x22100f8, 1, 'program_name', 'chown'),
    ],

    'relocs': [
        ('chown', 0x20f950, 2, 0x28a0),
        ('chown', 0x20f958, 2, 0x2860),
        ('chown', 0x20f960, 2, 0xb19a),
        ('chown', 0x20f980, 2, 0xb1a4),
        ('chown', 0x20f9a0, 2, 0xb1b4),
        ('chown', 0x20f9c0, 2, 0xb1ac),
        ('chown', 0x20f9e0, 2, 0xb1b1),
        ('chown', 0x20fa00, 2, 0xb1c0),
        ('chown', 0x20fa20, 2, 0xb1c3),
        ('chown', 0x20fa40, 2, 0xb1d1),
        ('chown', 0x20fa60, 2, 0xb1d7),
        ('chown', 0x20fa80, 2, 0xb1b6),
        ('chown', 0x20faa0, 2, 0xb1de),
        ('chown', 0x20fac0, 2, 0xb1e6),
        ('chown', 0x20fae0, 2, 0xb1eb),
        ('chown', 0x20fb20, 2, 0xc141),
        ('chown', 0x20fb28, 2, 0xc149),
        ('chown', 0x20fb30, 2, 0xc14f),
        ('chown', 0x20fb38, 2, 0xc15c),
        ('chown', 0x20fb40, 2, 0xc169),
        ('chown', 0x20fb48, 2, 0xcb40),
        ('chown', 0x20fb50, 2, 0xc17d),
        ('chown', 0x20fb58, 2, 0xc162),
        ('chown', 0x20fb60, 2, 0xb13d),
        ('chown', 0x20fb68, 2, 0xc185),
        ('chown', 0x210008, 2, 0x210008),
        ('chown', 0x210010, 2, 0xc0d4),
        ('chown', 0x210060, 2, 0x210070),
        ('chown', 0x210078, 2, 0x210100),
        ('chown', 0x210080, 0, 0),
        ('chown', 0x210088, 0, 0),
        ('chown', 0x210090, 0, 0),
        ('chown', 0x2100a0, 0, 0),
        ('chown', 0x2100a8, 0, 0),
        ('chown', 0x2100c0, 0, 0),
    ],

    'names': [
        (0x2001d38, 'chown.init_function'),
        (0x2001d60, 'chown.plt_endgrent'),
        (0x2001d70, 'chown.plt___uflow'),
        (0x2001d80, 'chown.plt_getenv'),
        (0x2001d90, 'chown.plt_abort'),
        (0x2001da0, 'chown.plt___errno_location'),
        (0x2001db0, 'chown.plt_strncmp'),
        (0x2001dc0, 'chown.plt__exit'),
        (0x2001dd0, 'chown.plt_strcpy'),
        (0x2001de0, 'chown.plt___fpending'),
        (0x2001df0, 'chown.plt_qsort'),
        (0x2001e00, 'chown.plt_fcntl'),
        (0x2001e10, 'chown.plt_textdomain'),
        (0x2001e20, 'chown.plt_fclose'),
        (0x2001e30, 'chown.plt_getpwuid'),
        (0x2001e40, 'chown.plt_bindtextdomain'),
        (0x2001e50, 'chown.plt_stpcpy'),
        (0x2001e60, 'chown.plt_dcgettext'),
        (0x2001e70, 'chown.plt___ctype_get_mb_cur_max'),
        (0x2001e80, 'chown.plt_strlen'),
        (0x2001e90, 'chown.plt___lxstat'),
        (0x2001ea0, 'chown.plt_openat'),
        (0x2001eb0, 'chown.plt___stack_chk_fail'),
        (0x2001ec0, 'chown.plt_getopt_long'),
        (0x2001ed0, 'chown.plt_mbrtowc'),
        (0x2001ee0, 'chown.plt_strchr'),
        (0x2001ef0, 'chown.plt_getgrgid'),
        (0x2001f00, 'chown.plt___fxstatat'),
        (0x2001f10, 'chown.plt_strrchr'),
        (0x2001f20, 'chown.plt_lseek'),
        (0x2001f30, 'chown.plt___assert_fail'),
        (0x2001f40, 'chown.plt_memset'),
        (0x2001f50, 'chown.plt_fscanf'),
        (0x2001f60, 'chown.plt_close'),
        (0x2001f70, 'chown.plt___openat_2'),
        (0x2001f80, 'chown.plt_closedir'),
        (0x2001f90, 'chown.plt_memcmp'),
        (0x2001fa0, 'chown.plt_fputs_unlocked'),
        (0x2001fb0, 'chown.plt_calloc'),
        (0x2001fc0, 'chown.plt_strcmp'),
        (0x2001fd0, 'chown.plt_dirfd'),
        (0x2001fe0, 'chown.plt_getpwnam'),
        (0x2001ff0, 'chown.plt_memcpy'),
        (0x2002000, 'chown.plt_getgrnam'),
        (0x2002010, 'chown.plt_fileno'),
        (0x2002020, 'chown.plt___xstat'),
        (0x2002030, 'chown.plt_readdir'),
        (0x2002040, 'chown.plt_malloc'),
        (0x2002050, 'chown.plt_fflush'),
        (0x2002060, 'chown.plt_nl_langinfo'),
        (0x2002070, 'chown.plt_ungetc'),
        (0x2002080, 'chown.plt___fxstat'),
        (0x2002090, 'chown.plt_endpwent'),
        (0x20020a0, 'chown.plt___freading'),
        (0x20020b0, 'chown.plt_fchdir'),
        (0x20020c0, 'chown.plt_realloc'),
        (0x20020d0, 'chown.plt_fdopen'),
        (0x20020e0, 'chown.plt_setlocale'),
        (0x20020f0, 'chown.plt___printf_chk'),
        (0x2002100, 'chown.plt_memmove'),
        (0x2002110, 'chown.plt_error'),
        (0x2002120, 'chown.plt_open'),
        (0x2002130, 'chown.plt_fseeko'),
        (0x2002140, 'chown.plt_fchown'),
        (0x2002150, 'chown.plt_fdopendir'),
        (0x2002160, 'chown.plt_strtoul'),
        (0x2002170, 'chown.plt_fstatfs'),
        (0x2002180, 'chown.plt___cxa_atexit'),
        (0x2002190, 'chown.plt_fchownat'),
        (0x20021a0, 'chown.plt_exit'),
        (0x20021b0, 'chown.plt_fwrite'),
        (0x20021c0, 'chown.plt___fprintf_chk'),
        (0x20021d0, 'chown.plt_mbsinit'),
        (0x20021e0, 'chown.plt_iswprint'),
        (0x20021f0, 'chown.plt___ctype_b_loc'),
        (0x2002200, 'chown.plt_free'),
        (0x2002208, 'chown.plt___cxa_finalize'),
        (0x20027a0, 'chown.__entry'),
        (0x2002860, 'chown.fini_function_0'),
        (0x20028a0, 'chown.init_function_0'),
        (0x2008420, 'chown.fts_open'),
        (0x20087c0, 'chown.fts_close'),
        (0x2008950, 'chown.fts_read'),
        (0x20090d0, 'chown.fts_set'),
        (0x2009100, 'chown.fts_children'),
        (0x200b08c, 'chown.fini_function'),
        (0x200b0a0, 'chown._IO_stdin_used'),
        (0x200c5e0, 'chown.quoting_style_vals'),
        (0x200c960, 'chown.version_etc_copyright'),
        (0x220f950, 'chown.ptr_init_function_0_0220f950'),
        (0x220f958, 'chown.ptr_fini_function_0_0220f958'),
        (0x220fb20, 'chown.quoting_style_args'),
        (0x220fd80, '*.endgrent_0220fd80'),
        (0x220fd88, '*.__uflow_0220fd88'),
        (0x220fd90, '*.getenv_0220fd90'),
        (0x220fd98, '*.abort_0220fd98'),
        (0x220fda0, '*.__errno_location_0220fda0'),
        (0x220fda8, '*.strncmp_0220fda8'),
        (0x220fdb0, '*._exit_0220fdb0'),
        (0x220fdb8, '*.strcpy_0220fdb8'),
        (0x220fdc0, '*.__fpending_0220fdc0'),
        (0x220fdc8, '*.qsort_0220fdc8'),
        (0x220fdd0, '*.fcntl_0220fdd0'),
        (0x220fdd8, '*.textdomain_0220fdd8'),
        (0x220fde0, '*.fclose_0220fde0'),
        (0x220fde8, '*.getpwuid_0220fde8'),
        (0x220fdf0, '*.bindtextdomain_0220fdf0'),
        (0x220fdf8, '*.stpcpy_0220fdf8'),
        (0x220fe00, '*.dcgettext_0220fe00'),
        (0x220fe08, '*.__ctype_get_mb_cur_max_0220fe08'),
        (0x220fe10, '*.strlen_0220fe10'),
        (0x220fe18, '*.__lxstat_0220fe18'),
        (0x220fe20, '*.openat_0220fe20'),
        (0x220fe28, '*.__stack_chk_fail_0220fe28'),
        (0x220fe30, '*.getopt_long_0220fe30'),
        (0x220fe38, '*.mbrtowc_0220fe38'),
        (0x220fe40, '*.strchr_0220fe40'),
        (0x220fe48, '*.getgrgid_0220fe48'),
        (0x220fe50, '*.__fxstatat_0220fe50'),
        (0x220fe58, '*.strrchr_0220fe58'),
        (0x220fe60, '*.lseek_0220fe60'),
        (0x220fe68, '*.__assert_fail_0220fe68'),
        (0x220fe70, '*.memset_0220fe70'),
        (0x220fe78, '*.fscanf_0220fe78'),
        (0x220fe80, '*.close_0220fe80'),
        (0x220fe88, '*.__openat_2_0220fe88'),
        (0x220fe90, '*.closedir_0220fe90'),
        (0x220fe98, '*.memcmp_0220fe98'),
        (0x220fea0, '*.fputs_unlocked_0220fea0'),
        (0x220fea8, '*.calloc_0220fea8'),
        (0x220feb0, '*.strcmp_0220feb0'),
        (0x220feb8, '*.dirfd_0220feb8'),
        (0x220fec0, '*.getpwnam_0220fec0'),
        (0x220fec8, '*.memcpy_0220fec8'),
        (0x220fed0, '*.getgrnam_0220fed0'),
        (0x220fed8, '*.fileno_0220fed8'),
        (0x220fee0, '*.__xstat_0220fee0'),
        (0x220fee8, '*.readdir_0220fee8'),
        (0x220fef0, '*.malloc_0220fef0'),
        (0x220fef8, '*.fflush_0220fef8'),
        (0x220ff00, '*.nl_langinfo_0220ff00'),
        (0x220ff08, '*.ungetc_0220ff08'),
        (0x220ff10, '*.__fxstat_0220ff10'),
        (0x220ff18, '*.endpwent_0220ff18'),
        (0x220ff20, '*.__freading_0220ff20'),
        (0x220ff28, '*.fchdir_0220ff28'),
        (0x220ff30, '*.realloc_0220ff30'),
        (0x220ff38, '*.fdopen_0220ff38'),
        (0x220ff40, '*.setlocale_0220ff40'),
        (0x220ff48, '*.__printf_chk_0220ff48'),
        (0x220ff50, '*.memmove_0220ff50'),
        (0x220ff58, '*.error_0220ff58'),
        (0x220ff60, '*.open_0220ff60'),
        (0x220ff68, '*.fseeko_0220ff68'),
        (0x220ff70, '*.fchown_0220ff70'),
        (0x220ff78, '*.fdopendir_0220ff78'),
        (0x220ff80, '*.strtoul_0220ff80'),
        (0x220ff88, '*.fstatfs_0220ff88'),
        (0x220ff90, '*.__cxa_atexit_0220ff90'),
        (0x220ff98, '*.fchownat_0220ff98'),
        (0x220ffa0, '*.exit_0220ffa0'),
        (0x220ffa8, '*.fwrite_0220ffa8'),
        (0x220ffb0, '*.__fprintf_chk_0220ffb0'),
        (0x220ffb8, '*.mbsinit_0220ffb8'),
        (0x220ffc0, '*.iswprint_0220ffc0'),
        (0x220ffc8, '*.__ctype_b_loc_0220ffc8'),
        (0x220ffd0, '*.free_0220ffd0'),
        (0x220ffd8, '*._ITM_deregisterTMCloneTable_0220ffd8'),
        (0x220ffe0, '*.__libc_start_main_0220ffe0'),
        (0x220ffe8, '*.__gmon_start___0220ffe8'),
        (0x220fff0, '*._ITM_registerTMCloneTable_0220fff0'),
        (0x220fff8, '*.__cxa_finalize_0220fff8'),
        (0x2210010, 'chown.Version'),
        (0x2210018, 'chown.exit_failure'),
        (0x2210020, 'chown.quote_quoting_options'),
        (0x2210080, 'chown.program_invocation_short_name'),
        (0x2210088, 'chown.stdout'),
        (0x2210090, 'chown.optind'),
        (0x22100a0, 'chown.optarg'),
        (0x22100a8, 'chown.__progname_full'),
        (0x22100c0, 'chown.stderr'),
        (0x22100f8, 'chown.program_name'),
    ],

    'pltgot': [
    ],

}
